@@ -42,6 +42,10 @@ int Help()
     TEXTOUT("                    Full information Display with XML tags");
     TEXTOUT("--Output=EBUCore");
     TEXTOUT("                    Full information Display with EBUCore compliant XML tags");
+    TEXTOUT("--Output=PBCore");
+    TEXTOUT("                    Full information Display with PBCore compliant XML tags");
+    TEXTOUT("--Output=PBCore2");
+    TEXTOUT("                    Full information Display with PBCore 2.0 compliant XML tags");
     TEXTOUT("--Output=...y");
     TEXTOUT("                    Template defined information Display");
     TEXTOUT("--Info-Parameters");
@@ -49,6 +53,10 @@ int Help()
     TEXTOUT("");
     TEXTOUT("--Language=raw");
     TEXTOUT("                    Display non-translated unique identifiers (internal text)");
+    TEXTOUT("--Details=1");
+    TEXTOUT("                    Display mediatrace info");
+    TEXTOUT("--File_TestContinuousFileNames=0");
+    TEXTOUT("                    Disable image sequence detection");
     TEXTOUT("--LogFile=...");
     TEXTOUT("                    Save the output in the specified file");
     TEXTOUT("--BOM");
@@ -108,7 +116,7 @@ int Help()
     TEXTOUT("                    (you don't need to accept the key with ssh first)");
     TEXTOUT("                    Use it at your own risks");
 
-    return -1;
+    return MI_OK;
 }
 
 //---------------------------------------------------------------------------
@@ -117,7 +125,7 @@ int Help_Nothing()
     TEXTOUT("Usage: \"MediaInfo [-Options...] FileName1 [Filename2...]\"");
     TEXTOUT("\"MediaInfo --Help\" for displaying more information");
 
-    return -1;
+    return MI_OK;
 }
 
 //---------------------------------------------------------------------------
@@ -144,7 +152,7 @@ int Help_Output()
     TEXTOUT("\"Video;%DisplayAspectRatio%\"  for Video Aspect Ratio.");
     TEXTOUT("\"Audio;%Format%\"              for Audio Format.");
 
-    return -1;
+    return MI_ERROR;
 }
 
 //---------------------------------------------------------------------------
@@ -153,6 +161,13 @@ int Help_Security()
     TEXTOUT("Usage: \"MediaInfo [-Options...] FileName1 [Filename2...]\"");
     TEXTOUT("\"MediaInfo --Help\" for displaying more information");
 
-    return -1;
+    return MI_OK;
 }
 
+
+//---------------------------------------------------------------------------
+int Usage()
+{
+    Help_Nothing();
+    return MI_ERROR;
+}
