@@ -560,6 +560,8 @@ int Preferences::ExplorerShell()
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
         ".tak;TakVideoFile\r\n"
+	".tif;TIFFFile\r\n"
+	".tiff;TIFFFile\r\n"
         ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
@@ -1149,6 +1151,8 @@ int Preferences::ShellToolTip()
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
         ".tak;TAKFile\r\n"
+	".tif;TIFFFile\r\n"
+	".tiff;TIFFFile\r\n"
         ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
