@@ -95,12 +95,42 @@ void TExportF::Name_Adapt()
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
+    else if (Export->ActivePage==Export_PBCore2)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
     else if (Export->ActivePage==Export_EBUCore_1_5)
     {
         FN.Extension_Set(__T("xml"));
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
+    else if (Export->ActivePage==Export_EBUCore_1_6)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
+    else if (Export->ActivePage==Export_FIMS_1_1)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
+    else if (Export->ActivePage==Export_FIMS_1_2)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
+    else if (Export->ActivePage==Export_FIMS_1_3)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
     else if (Export->ActivePage==Export_reVTMD)
     {
         FN.Extension_Set(__T("xml"));
@@ -145,8 +175,18 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
         Export->ActivePage=Export_MPEG7;
     else if (Info==__T("PBCore_1.2"))
         Export->ActivePage=Export_PBCore;
+    else if (Info==__T("PBCore_2.0"))
+        Export->ActivePage=Export_PBCore2;
     else if (Info==__T("EBUCore_1.5"))
         Export->ActivePage=Export_EBUCore_1_5;
+    else if (Info==__T("EBUCore_1.6"))
+        Export->ActivePage=Export_EBUCore_1_6;
+    else if (Info==__T("FIMS_1.1"))
+        Export->ActivePage=Export_FIMS_1_1;
+    else if (Info==__T("FIMS_1.2"))
+        Export->ActivePage=Export_FIMS_1_2;
+    else if (Info==__T("FIMS_1.3"))
+        Export->ActivePage=Export_FIMS_1_3;
     else if (Info==__T("reVTMD"))
         Export->ActivePage=Export_reVTMD;
 
@@ -420,6 +460,22 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
+    else if (Export->ActivePage==Export_PBCore2)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("PBCore_2.0"));
+        if (Export_PBCore2_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".PBCore2.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
     else if (Export->ActivePage==Export_EBUCore_1_5)
     {
         ToExport->Option_Static(__T("Inform"), __T("EBUCore_1.5"));
@@ -436,6 +492,70 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
+    else if (Export->ActivePage==Export_EBUCore_1_6)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("EBUCore_1.6"));
+        if (Export_EBUCore_1_6_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".EBUCore.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+    else if (Export->ActivePage==Export_FIMS_1_1)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("FIMS_1.1"));
+        if (Export_FIMS_1_1_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".FIMS.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+    else if (Export->ActivePage==Export_FIMS_1_2)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("FIMS_1.2"));
+        if (Export_FIMS_1_2_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".FIMS.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+    else if (Export->ActivePage==Export_FIMS_1_3)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("FIMS_1.3"));
+        if (Export_FIMS_1_3_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".FIMS.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
     else if (Export->ActivePage==Export_reVTMD)
     {
         ToExport->Option_Static(__T("Inform"), __T("reVTMD"));
@@ -513,6 +633,13 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_PBCore_SideCar->Checked?false:true;;
     }
+    else if (Export->ActivePage==Export_PBCore2)
+    {
+        Export_PBCore2_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_PBCore2_SideCar->Checked?false:true;;
+    }
     else if (Export->ActivePage==Export_EBUCore_1_5)
     {
         Export_EBUCore_1_5_SideCarClick(Sender);
@@ -520,6 +647,34 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_EBUCore_1_5_SideCar->Checked?false:true;;
     }
+    else if (Export->ActivePage==Export_EBUCore_1_6)
+    {
+        Export_EBUCore_1_6_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_EBUCore_1_6_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_FIMS_1_1)
+    {
+        Export_FIMS_1_1_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_FIMS_1_1_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_FIMS_1_2)
+    {
+        Export_FIMS_1_2_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_FIMS_1_2_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_FIMS_1_3)
+    {
+        Export_FIMS_1_3_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_FIMS_1_3_SideCar->Checked?false:true;;
+    }
     else if (Export->ActivePage==Export_reVTMD)
     {
         Export_reVTMD_SideCarClick(Sender);
@@ -597,11 +752,42 @@ void __fastcall TExportF::Export_PBCore_SideCarClick(TObject *Sender)
 }
 //---------------------------------------------------------------------------
 
+void __fastcall TExportF::Export_PBCore2_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_PBCore2_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
 void __fastcall TExportF::Export_EBUCore_1_5_SideCarClick(TObject *Sender)
 {
     Name_Choose->Visible=Export_EBUCore_1_5_SideCar->Checked?false:true;
 }
 //---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_EBUCore_1_6_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_EBUCore_1_6_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_FIMS_1_1_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_FIMS_1_1_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_FIMS_1_2_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_FIMS_1_2_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_FIMS_1_3_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_FIMS_1_3_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
 void __fastcall TExportF::Export_reVTMD_SideCarClick(TObject *Sender)
 {
     Name_Choose->Visible=Export_reVTMD_SideCar->Checked?false:true;
